summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/commands.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/commands.cpp')
-rw-r--r--kexi/formeditor/commands.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kexi/formeditor/commands.cpp b/kexi/formeditor/commands.cpp
index c9bad809..241a1291 100644
--- a/kexi/formeditor/commands.cpp
+++ b/kexi/formeditor/commands.cpp
@@ -127,7 +127,7 @@ PropertyCommand::unexecute()
WidgetWithSubpropertiesInterface* subpropIface = dynamic_cast<WidgetWithSubpropertiesInterface*>(widg);
TQWidget *subWidget = (subpropIface && subpropIface->subwidget()) ? subpropIface->subwidget() : widg;
- if (-1!=subWidget->tqmetaObject()->findProperty( m_property, true ))
+ if (-1!=subWidget->metaObject()->findProperty( m_property, true ))
subWidget->setProperty(m_property, it.data());
}
@@ -438,7 +438,7 @@ AdjustSizeCommand::execute()
if(item && !item->tqchildren()->isEmpty()) { // container
TQSize s;
if(item->container() && item->container()->tqlayout())
- s = w->tqsizeHint();
+ s = w->sizeHint();
else
s = getSizeFromChildren(item);
// minimum size for containers
@@ -457,9 +457,9 @@ AdjustSizeCommand::execute()
else if(item && item->container()) // empty container
w->resize(item->container()->form()->gridSize() * 5, item->container()->form()->gridSize() * 5); // basic size
else {
- TQSize tqsizeHint(w->tqsizeHint());
- if (tqsizeHint.isValid())
- w->resize(tqsizeHint);
+ TQSize sizeHint(w->sizeHint());
+ if (sizeHint.isValid())
+ w->resize(sizeHint);
}
}
break;
@@ -755,7 +755,7 @@ InsertWidgetCommand::execute()
// if the insertRect is invalid (ie only one point), we use widget' size hint
if(( (m_insertRect.width() < 21) && (m_insertRect.height() < 21)))
{
- TQSize s = w->tqsizeHint();
+ TQSize s = w->sizeHint();
if(s.isEmpty())
s = TQSize(20, 20); // Minimum size to avoid creating a (0,0) widget
@@ -912,7 +912,7 @@ CreateLayoutCommand::execute()
container->setSelectedWidget(0, false);
w->move(m_pos.begin().data().topLeft()); // we move the tqlayout at the position of the topleft widget
// tqsizeHint of these widgets depends on tqgeometry, so give them appropriate tqgeometry
if(m_type == Container::HFlow)
w->resize( TQSize(700, 20) );
else if(m_type == Container::VFlow)
@@ -938,7 +938,7 @@ CreateLayoutCommand::execute()
((TQSplitter*)w)->setOrientation(Qt::Vertical);
else if(tree->container()) {
tree->container()->setLayout((Container::LayoutType)m_type);
- w->resize(tree->container()->tqlayout()->tqsizeHint()); // the tqlayout doesn't have its own size
+ w->resize(tree->container()->tqlayout()->sizeHint()); // the tqlayout doesn't have its own size
}
container->setSelectedWidget(w, false);
@@ -1249,13 +1249,13 @@ PasteWidgetCommand::fixPos(TQDomElement &el, Container *container)
int rh = h.text().toInt();
TQRect r(rx, ry, rw, rh);
- TQWidget *w = m_form->widget()->tqchildAt(r.x() + 6, r.y() + 6, false);
+ TQWidget *w = m_form->widget()->childAt(r.x() + 6, r.y() + 6, false);
if(!w)
return;
while((w->tqgeometry() == r) && (w != 0))// there is already a widget there, with the same size
{
- w = m_form->widget()->tqchildAt(w->x() + 16, w->y() + 16, false);
+ w = m_form->widget()->childAt(w->x() + 16, w->y() + 16, false);
r.moveBy(10,10);
}
@@ -1300,11 +1300,11 @@ PasteWidgetCommand::moveWidgetBy(TQDomElement &el, Container *container, const T
TQRect r(rx + p.x(), ry + p.y(), rw, rh);
kdDebug() << "Moving widget by " << p << " from " << rx << " " << ry << " to " << r.topLeft() << endl;
- TQWidget *w = m_form->widget()->tqchildAt(r.x() + 6, r.y() + 6, false);
+ TQWidget *w = m_form->widget()->childAt(r.x() + 6, r.y() + 6, false);
while(w && (w->tqgeometry() == r))// there is already a widget there, with the same size
{
- w = m_form->widget()->tqchildAt(w->x() + 16, w->y() + 16, false);
+ w = m_form->widget()->childAt(w->x() + 16, w->y() + 16, false);
r.moveBy(10,10);
}
@@ -912,7 +912,7 @@ CreateLayoutCommand::execute()
container->setSelectedWidget(0, false);
w->move(m_pos.begin().data().topLeft()); // we move the tqlayout at the position of the topleft widget
- // tqsizeHint of these widgets depends on tqgeometry, so give them appropriate tqgeometry
+ // sizeHint of these widgets depends on tqgeometry, so give them appropriate tqgeometry
if(m_type == Container::HFlow)
w->resize( TQSize(700, 20) );